@@ -7,6 +7,6 @@
 
 #define ZATHURA_DJVU_SCALE 0.2
 
-GIRARA_HIDDEN void handle_messages(djvu_document_t* document, bool wait);
+void handle_messages(djvu_document_t* document, bool wait);
 
 #endif // DJVU_INTERNAL_H
